@@ -26,10 +26,10 @@
 
 #include "kxmlrpcclient_export.h"
 
-#include <QtCore/QUrl>
-#include <QtCore/QList>
-#include <QtCore/QObject>
-#include <QtCore/QVariant>
+#include <QUrl>
+#include <QList>
+#include <QObject>
+#include <QVariant>
 class ClientPrivate;
 
 /** Names for XmlRpc related classes */
@@ -37,6 +37,8 @@ namespace KXmlRpc
 {
 
 /**
+  @class Client client.h <KXmlRpcClient/Client>
+
   @brief
   A class that represents a connection to a XML-RPC server.
   This is the main interface to the XML-RPC client library.
